@@ -6,7 +6,6 @@ use sqlx::postgres::{PgPoolOptions, PgRow, Postgres};
 use sqlx::{Column, Connection, Executor, Row, Statement, TypeInfo};
 use sqlx_test::{new, setup_if_needed};
 use std::env;
-use std::thread;
 use std::time::Duration;
 
 #[sqlx_macros::test]
@@ -505,11 +504,7 @@ async fn it_can_drop_multiple_transactions() -> anyhow::Result<()> {
 #[ignore]
 #[sqlx_macros::test]
 async fn pool_smoke_test() -> anyhow::Result<()> {
-    #[cfg(any(feature = "_rt-tokio", feature = "_rt-actix"))]
-    use tokio::{task::spawn, time::sleep, time::timeout};
-
-    #[cfg(feature = "_rt-async-std")]
-    use async_std::{future::timeout, task::sleep, task::spawn};
+    use futures::{future, task::Poll, Future};
 
     eprintln!("starting pool");
 
@@ -523,7 +518,7 @@ async fn pool_smoke_test() -> anyhow::Result<()> {
     // spin up more tasks than connections available, and ensure we don't deadlock
     for i in 0..20 {
         let pool = pool.clone();
-        spawn(async move {
+        sqlx_rt::spawn(async move {
             loop {
                 if let Err(e) = sqlx::query("select 1 + 1").execute(&pool).await {
                     eprintln!("pool task {} dying due to {}", i, e);
@@ -535,26 +530,32 @@ async fn pool_smoke_test() -> anyhow::Result<()> {
 
     for _ in 0..5 {
         let pool = pool.clone();
-        // we don't need async, just need this to run concurrently
-        // if we use `task::spawn()` we risk starving the event loop because we don't yield
-        thread::spawn(move || {
+        sqlx_rt::spawn(async move {
             while !pool.is_closed() {
-                // drop acquire() futures in a hot loop
-                // https://github.com/launchbadge/sqlx/issues/83
-                drop(pool.acquire());
+                let acquire = pool.acquire();
+                futures::pin_mut!(acquire);
+
+                // poll the acquire future once to put the waiter in the queue
+                future::poll_fn(move |cx| {
+                    let _ = acquire.as_mut().poll(cx);
+                    Poll::Ready(())
+                })
+                .await;
+
+                sqlx_rt::yield_now().await;
             }
         });
     }
 
     eprintln!("sleeping for 30 seconds");
 
-    sleep(Duration::from_secs(30)).await;
+    sqlx_rt::sleep(Duration::from_secs(30)).await;
 
     // assert_eq!(pool.size(), 10);
 
     eprintln!("closing pool");
 
-    timeout(Duration::from_secs(30), pool.close()).await?;
+    sqlx_rt::timeout(Duration::from_secs(30), pool.close()).await?;
 
     eprintln!("pool closed successfully");
 
@@ -887,3 +888,180 @@ from (values (null)) vals(val)
 
     Ok(())
 }
+
+#[sqlx_macros::test]
+async fn test_listener_cleanup() -> anyhow::Result<()> {
+    #[cfg(any(feature = "_rt-tokio", feature = "_rt-actix"))]
+    use tokio::time::timeout;
+
+    #[cfg(feature = "_rt-async-std")]
+    use async_std::future::timeout;
+
+    use sqlx::pool::PoolOptions;
+    use sqlx::postgres::PgListener;
+
+    // Create a connection on which to send notifications
+    let mut notify_conn = new::<Postgres>().await?;
+
+    // Create a pool with exactly one connection so we can
+    // deterministically test the cleanup.
+    let pool = PoolOptions::<Postgres>::new()
+        .min_connections(1)
+        .max_connections(1)
+        .test_before_acquire(true)
+        .connect(&env::var("DATABASE_URL")?)
+        .await?;
+
+    let mut listener = PgListener::connect_with(&pool).await?;
+    listener.listen("test_channel").await?;
+
+    // Checks for a notification on the test channel
+    async fn try_recv(listener: &mut PgListener) -> anyhow::Result<bool> {
+        match timeout(Duration::from_millis(100), listener.recv()).await {
+            Ok(res) => {
+                res?;
+                Ok(true)
+            }
+            Err(_) => Ok(false),
+        }
+    }
+
+    // Check no notification is received before one is sent
+    assert!(!try_recv(&mut listener).await?, "Notification not sent");
+
+    // Check notification is sent and received
+    notify_conn.execute("NOTIFY test_channel").await?;
+    assert!(
+        try_recv(&mut listener).await?,
+        "Notification sent and received"
+    );
+    assert!(
+        !try_recv(&mut listener).await?,
+        "Notification is not duplicated"
+    );
+
+    // Test that cleanup stops listening on the channel
+    drop(listener);
+    let mut listener = PgListener::connect_with(&pool).await?;
+
+    // Check notification is sent but not received
+    notify_conn.execute("NOTIFY test_channel").await?;
+    assert!(
+        !try_recv(&mut listener).await?,
+        "Notification is not received on fresh listener"
+    );
+
+    Ok(())
+}
+
+#[sqlx_macros::test]
+async fn it_supports_domain_types_in_composite_domain_types() -> anyhow::Result<()> {
+    #[derive(Copy, Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
+    struct MonthId(i16);
+
+    impl sqlx::Type<Postgres> for MonthId {
+        fn type_info() -> sqlx::postgres::PgTypeInfo {
+            sqlx::postgres::PgTypeInfo::with_name("month_id")
+        }
+
+        fn compatible(ty: &sqlx::postgres::PgTypeInfo) -> bool {
+            *ty == Self::type_info()
+        }
+    }
+
+    impl<'r> sqlx::Decode<'r, Postgres> for MonthId {
+        fn decode(
+            value: sqlx::postgres::PgValueRef<'r>,
+        ) -> Result<Self, Box<dyn std::error::Error + 'static + Send + Sync>> {
+            Ok(Self(<i16 as sqlx::Decode<Postgres>>::decode(value)?))
+        }
+    }
+
+    impl<'q> sqlx::Encode<'q, Postgres> for MonthId {
+        fn encode_by_ref(
+            &self,
+            buf: &mut sqlx::postgres::PgArgumentBuffer,
+        ) -> sqlx::encode::IsNull {
+            self.0.encode(buf)
+        }
+    }
+
+    #[derive(Copy, Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
+    struct WinterYearMonth {
+        year: i32,
+        month: MonthId,
+    }
+
+    impl sqlx::Type<Postgres> for WinterYearMonth {
+        fn type_info() -> sqlx::postgres::PgTypeInfo {
+            sqlx::postgres::PgTypeInfo::with_name("winter_year_month")
+        }
+
+        fn compatible(ty: &sqlx::postgres::PgTypeInfo) -> bool {
+            *ty == Self::type_info()
+        }
+    }
+
+    impl<'r> sqlx::Decode<'r, Postgres> for WinterYearMonth {
+        fn decode(
+            value: sqlx::postgres::PgValueRef<'r>,
+        ) -> Result<Self, Box<dyn std::error::Error + 'static + Send + Sync>> {
+            let mut decoder = sqlx::postgres::types::PgRecordDecoder::new(value)?;
+
+            let year = decoder.try_decode::<i32>()?;
+            let month = decoder.try_decode::<MonthId>()?;
+
+            Ok(Self { year, month })
+        }
+    }
+
+    impl<'q> sqlx::Encode<'q, Postgres> for WinterYearMonth {
+        fn encode_by_ref(
+            &self,
+            buf: &mut sqlx::postgres::PgArgumentBuffer,
+        ) -> sqlx::encode::IsNull {
+            let mut encoder = sqlx::postgres::types::PgRecordEncoder::new(buf);
+            encoder.encode(self.year);
+            encoder.encode(self.month);
+            encoder.finish();
+            sqlx::encode::IsNull::No
+        }
+    }
+
+    let mut conn = new::<Postgres>().await?;
+
+    {
+        let result = sqlx::query("DELETE FROM heating_bills;")
+            .execute(&mut conn)
+            .await;
+
+        let result = result.unwrap();
+        assert_eq!(result.rows_affected(), 1);
+    }
+
+    {
+        let result = sqlx::query(
+            "INSERT INTO heating_bills(month, cost) VALUES($1::winter_year_month, 100);",
+        )
+        .bind(WinterYearMonth {
+            year: 2021,
+            month: MonthId(1),
+        })
+        .execute(&mut conn)
+        .await;
+
+        let result = result.unwrap();
+        assert_eq!(result.rows_affected(), 1);
+    }
+
+    {
+        let result = sqlx::query("DELETE FROM heating_bills;")
+            .execute(&mut conn)
+            .await;
+
+        let result = result.unwrap();
+        assert_eq!(result.rows_affected(), 1);
+    }
+
+    Ok(())
+}
